|python-versions| |github-build| |docs|

pyavb
=====

A python module for reading and writing Avid Bin Files (AVB) files.

Notice
------

This project is in no way affiliated, nor endorsed in any way with Avid, and their name and all product names are registered brand names and trademarks that belong to them.

Requirements
------------

- Python >= 2.7

Installation
------------

You can install pyavb via::

    pip install pyavb

or clone the latest development git master::

    git clone https://github.com/markreidvfx/pyavb
    cd pyavb
    python setup.py install

Documentation
-------------

Documentation is available on `Read the Docs. <http://pyavb.readthedocs.io/>`_


.. |python-versions| image:: https://img.shields.io/badge/python-%3E%3D%202.7-blue.svg

.. |github-build| image:: https://github.com/markreidvfx/pyavb/actions/workflows/workflow.yml/badge.svg
    :alt: github actions
    :target: https://github.com/markreidvfx/pyavb/actions

.. |docs| image:: https://readthedocs.org/projects/pyavb/badge/?version=latest
    :alt: Documentation Status
    :target: http://pyavb.readthedocs.io/en/latest/?badge=latest
